@@ -10,11 +10,13 @@
 #############################################
 
 from semantyk.uuid_generator import generate_uuid
+from semantyk.namespace import RDFS, SMTK
 from rdflib import Literal, URIRef
 
 class Graph(object):
     id:str
     triples:set
+    uri:URIRef
 
     def add(self, s, p:URIRef, o):
         self.triples.add((s,p,o))
@@ -182,9 +184,10 @@ class Graph(object):
         self.triples.remove(old_triple)
         self.triples.add(new_triple)
 
-    def __init__(self, id:str = None, triples:set = None):
+    def __init__(self, id:str = None, triples:set = None, uri:URIRef = None):
         self.id = id or generate_uuid()
         self.triples = triples
+        self.uri = uri or URIRef(str(SMTK) + self.id)
 
     def __iter__(self):
         for triple in self.triples:
